Package: tidyomics
Title: Easily install and load the tidyomics ecosystem
Version: 1.9.0
Authors@R: c(
    person(given = "Stefano",
           family = "Mangiola",
           role = c("aut", "cre"),
           email = "mangiolastefano@gmail.com",
           comment = c(ORCID = "0000-0001-7474-836X")),
    person(given = "Michael",
           family = "Love",
           role = c("aut"),
           email = "michaelisaiahlove@gmail.com",
           comment = c(ORCID = "0000-0001-8401-0545")),
    person(given = "William",
           family = "Hutchison",
           role = c("aut"),
           email = "hutchison.w@wehi.edu.au",
           comment = c(ORCID = "0009-0001-6242-4269"))
	   )
Description: The tidyomics ecosystem is a set of packages for ’omic data analysis that work 
    together in harmony; they share common data representations and API design, consistent with the
    tidyverse ecosystem. The tidyomics package is designed to make it easy to install and load core 
    packages from the tidyomics ecosystem with a single command.
License: MIT + file LICENSE
URL: https://github.com/tidyomics/tidyomics
BugReports: https://github.com/tidyomics/tidyomics/issues
Depends: R (>= 4.2)
Imports: tidySummarizedExperiment, tidySingleCellExperiment,
        tidySpatialExperiment, tidyseurat, plyranges, purrr, rlang,
        stringr, cli,
Suggests: utils, tidyr, dplyr, tibble, ggplot2, mockr (>= 0.2.0), knitr
        (>= 1.41), rmarkdown (>= 2.20), testthat (>= 3.1.6),
        nullranges, tidybulk, plyinteractions
VignetteBuilder: knitr
Biarch: true
biocViews: AssayDomain, Infrastructure, RNASeq, DifferentialExpression,
        GeneExpression, Normalization, Clustering, QualityControl,
        Sequencing, Transcription, Transcriptomics
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/tidyomics
git_branch: devel
git_last_commit: a7fbe5a
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:34:57 UTC; biocbuild
Author: Stefano Mangiola [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7474-836X>),
  Michael Love [aut] (ORCID: <https://orcid.org/0000-0001-8401-0545>),
  William Hutchison [aut] (ORCID:
    <https://orcid.org/0009-0001-6242-4269>)
Maintainer: Stefano Mangiola <mangiolastefano@gmail.com>
